@@ -1,4 +1,4 @@
-## ----setup, echo = FALSE, results = "hide", message = FALSE--------------
+## ----setup, echo = FALSE, results = "hide", message = FALSE, warning = FALSE----
 set.seed(290875)
 
 sapply(c("mlt", "survival", "eha", "prodlim", "truncreg", "lattice", "gridExtra",
@@ -7,7 +7,7 @@ sapply(c("mlt", "survival", "eha", "prodlim", "truncreg", "lattice", "gridExtra"
 
 if (!file.exists("analysis/DVC.rda")) {
     download.file("https://zenodo.org/record/17179/files/DVC.tgz", "DVC.tgz")
-    untar("DVC.tgz", file = "analysis/DVC.rda", compressed = "gzip")
+    untar("DVC.tgz", file = "analysis/DVC.rda")
 }
 load("analysis/DVC.rda")
 dvc <- c(margin.table(obs, 2))
